import sys


def main():
    if len(sys.argv) > 1:
        print("debug 1")

    else:
        print("debug 2")


if __name__ == "__main__":
    main()
